//账号接口
import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import accountApi from "../api/accountApi";
import { request } from "../globalConfiguration";
const PublicData = {
  ids: undefined,
  activateType: undefined,
  activateDate: undefined,
  lock: undefined,
  roleId: undefined,
  roleName: undefined,
  userId: undefined,
  email: undefined,
  captcha: undefined,
  checkCode: undefined,
  phone: undefined,
};

// 查询返回的数据
function publicDataConvert(result) {
  return {
    id: result.id || undefined,
    accountType: result.zhlx || undefined,
    account: result.zh || undefined,
    name: result.xm || undefined,
    password: result.mm || undefined,
    email: result.yx || undefined,
    phone: result.sjhm || undefined,
    userNumber: result.cid || undefined,
    orgId: result.fkJgId || undefined,
    orgName: result.fkJgMc || undefined,
    professionalId: result.fkXszyId || undefined, //专业Id
    professionalName: result.fkXszyMc || undefined, //专业名称
    adminClassId: result.fkXzbId || undefined, //行政班id
    adminClassName: result.fkXzbMc || undefined, //行政班名称
    loginSupport: result.dlzc || undefined,
    accountStartDate: result.zhyxqqr || undefined,
    accountEndDate: result.zhyxqzr || undefined,
    oneCardNumber: result.yktkh || undefined,
    oneCardStartDate: result.yktyxqqr || undefined,
    oneCardEndDate: result.yktyxqzr || undefined,
    roleName: result.fkJsKey || undefined,
    roleId: result.fkJsVal || undefined,
    avatarId: result.gertx || undefined,
    accountTypeName: result.zhlxmc || undefined,
    accountStatus: result.accountStatus || undefined,
    avatarUrl: result.iconUrl || undefined,
    teacherLevel: result.jsdj || undefined,
    StudentDesignation: result.jszc || undefined,
    gender: result.xb || undefined,
    age: result.nl || undefined,
    birthdayDate: result.csrq || undefined,
  };
}

/**
 * @Post 请求
 *   激活
 * @param {*} data
 * {ids} 要激活的ids  用户id数组 []   *
 * {activateType} 激活类型  [account,metro_card] = [账号,一卡通]  *
 * {activateDate} 激活日期  [always,date] = [永久,指定日期] *
 * @param {*} config
 * @returns
 */
function activeUser(data = PublicData, config = {}) {
  return request(
    submit(
      {
        ids: data.ids || undefined,
        active_type: data.activateDate || undefined,
        bus_type: data.activateType || undefined,
      },
      accountApi.activeUser,
      config
    )
  );
}

/**
 * @Post 请求
 *   锁定/解锁
 * @param {*} data
 * {ids} 要锁定/解锁 的ids 用户id数组 [] *
 * {lock} 是否解锁或锁定  true = 锁定，false = 解锁 *
 * @param {*} config
 * @returns
 */
function lockUser(data = PublicData, config = {}) {
  return request(
    submit(
      {
        ids: data.ids || undefined,
        flag_lock: data.lock || undefined,
      },
      accountApi.lockUser,
      config
    )
  );
}

/**
 * @Post 请求
 *   锁定/解锁
 * @param {*} data
 * {ids} 要配置的ids  传入用户id数组 [] *
 * {roleId} 角色id *
 * {roleName} 角色名称 *
 * @param {*} config
 * @returns
 */
function configRoles(data = PublicData, config = {}) {
  return request(
    submit(
      {
        ids: data.ids || undefined,
        role_id: data.roleId || undefined,
        role_name: data.roleName || undefined,
      },
      accountApi.configRoles,
      config
    )
  );
}

/**
 *批量删除账号
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchUser(data, config = {}) {
  return request(batchDeletion(data, accountApi.delBatchUser, config));
}

/**
 *  根据id查用户详细 - 不包含扩展数据
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getUserByIdPart(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, accountApi.getUserByIdPart, config))
      .then(({ result }) => {
        resolve(publicDataConvert(result));
      })
      .catch(() => {
        reject({});
      });
  });
}

/**
 *  根据id查用户详细 - 不包含扩展数据
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getUserById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, accountApi.getUserById, config))
      .then(({ result }) => {
        resolve(publicDataConvert(result));
      })
      .catch(() => {
        reject({});
      });
  });
}

/**
 * 查询用户列表 - 不包含扩展数据
 * @param {data} 参数
 * {accountName} 账号名称
 * {userNumber} 教工号/学号/编号
 * {collegeId} 学院id   数组 []
 * {collegeName} 学院姓名
 * {excludeIds} 排除id列表
 * {includeIds} 包含id列表
 * {oneCardNumber} 一卡通号
 * {accountType}账号类型
 * {name} 姓名
 * {roles} 角色列表
 * {orgId} 机构id 数组[]
 * {orgName} 机构姓名
 * {schoolId} 学校Id
 * {schoolName} 学校机构名
 * {showPassword} 是否包含密码, 默认隐藏 true or false
 * {status} 状态
 * {pageNo} 第几页
 * {pageSize} 每页数量
 * @param {config} 配置项
 * @returns
 */
function queryUserListPart(data = {}, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          accountType: data.accountType || undefined,
          account: data.accountName || undefined,
          cid: data.userNumber || undefined,
          collegeId: data.collegeId || undefined,
          collegeName: data.collegeName || undefined,
          excludeIds: data.excludeIds || undefined,
          includeIds: data.includeIds || undefined,
          jsdj: data.teacherLevel || undefined,
          jszc: data.StudentDesignation || undefined,
          metroCard: data.oneCardNumber || undefined,
          role: data.roles || undefined,
          name: data.name || undefined,
          orgId: data.orgId || undefined,
          schoolId: data.schoolId || undefined,
          schoolName: data.schoolName || undefined,
          showPassword: data.showPassword || undefined,
          status: data.status || undefined,
          pageNo: data.pageNo || undefined,
          pageSize: data.pageSize || undefined,
        },
        accountApi.queryUserListPart,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0 ? list.map((item) => publicDataConvert(item)) : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

/**
 * 查询用户列表 - 不包含扩展数据
 * @param {data} 参数
 * {accountName} 账号名称
 * {userNumber} 教工号/学号/编号
 * {collegeId} 学院id   数组 []
 * {collegeName} 学院姓名
 * {excludeIds} 排除id列表
 * {includeIds} 包含id列表
 * {oneCardNumber} 一卡通号
 * {accountType}账号类型
 * {name} 姓名
 * {orgId} 机构id 数组[]
 * {orgName} 机构姓名
 * {schoolId} 学校Id
 * {schoolName} 学校机构名
 * {showPassword} 是否包含密码, 默认隐藏 true or false
 * {status} 状态
 * {pageNo} 第几页
 * {pageSize} 每页数量
 * @param {config} 配置项
 * @returns
 */
function queryUserList(data = {}, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          accountType: data.accountType || undefined,
          account: data.accountName || undefined,
          cid: data.userNumber || undefined,
          collegeId: data.collegeId || undefined,
          collegeName: data.collegeName || undefined,
          excludeIds: data.excludeIds || undefined,
          includeIds: data.includeIds || undefined,
          jsdj: data.teacherLevel || undefined,
          jszc: data.StudentDesignation || undefined,
          metroCard: data.oneCardNumber || undefined,
          name: data.name || undefined,
          orgId: data.orgId || undefined,
          schoolId: data.schoolId || undefined,
          schoolName: data.schoolName || undefined,
          showPassword: data.showPassword || undefined,
          status: data.status || undefined,
          pageNo: data.pageNo || undefined,
          pageSize: data.pageSize || undefined,
        },
        accountApi.queryUserList,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0 ? list.map((item) => publicDataConvert(item)) : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

/**
 * 分页查询用户列表 - 不包含扩展数据
 * @param {data} 参数
 * {accountName} 账号名称
 * {userNumber} 教工号/学号/编号
 * {collegeId} 学院id   数组 []
 * {collegeName} 学院姓名
 * {excludeIds} 排除id列表
 * {includeIds} 包含id列表
 * {oneCardNumber} 一卡通号
 * {accountType}账号类型
 * {name} 姓名
 * {orgId} 机构id 数组[]
 * {orgName} 机构姓名
 * {schoolId} 学校Id
 * {schoolName} 学校机构名
 * {showPassword} 是否包含密码, 默认隐藏 true or false
 * {status} 状态
 * {pageNo} 第几页
 * {pageSize} 每页数量
 * @param {config} 配置项
 * @returns
 */
function listPagesUserPart(data = {}, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          accountType: data.accountType || undefined,
          account: data.accountName || undefined,
          cid: data.userNumber || undefined,
          collegeId: data.collegeId || undefined,
          collegeName: data.collegeName || undefined,
          excludeIds: data.excludeIds || undefined,
          includeIds: data.includeIds || undefined,
          jsdj: data.teacherLevel || undefined,
          jszc: data.StudentDesignation || undefined,
          metroCard: data.oneCardNumber || undefined,
          name: data.name || undefined,
          orgId: data.orgId || undefined,
          schoolId: data.schoolId || undefined,
          schoolName: data.schoolName || undefined,
          showPassword: data.showPassword || undefined,
          status: data.status || undefined,
          pageNo: data.pageNo || undefined,
          pageSize: data.pageSize || undefined,
        },
        accountApi.listPagesUserPart,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0 ? list.map((item) => publicDataConvert(item)) : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

/**
 * 分页查询用户列表 - 包含扩展数据
 * @param {data} 参数
 * {accountName} 账号名称
 * {accountType}账号类型
 * {userNumber} 教工号/学号/编号
 * {collegeId} 学院id   数组 []
 * {collegeName} 学院姓名
 * {excludeIds} 排除id列表
 * {includeIds} 包含id列表
 * {oneCardNumber} 一卡通号
 * {name} 姓名
 * {orgId} 机构id 数组[]
 * {orgName} 机构姓名
 * {schoolId} 学校Id
 * {schoolName} 学校机构名
 * {showPassword} 是否包含密码, 默认隐藏 true or false
 * {status} 状态
 * {pageNo} 第几页
 * {pageSize} 每页数量
 * @param {config} 配置项
 * @returns
 */
function listPagesUser(data = {}, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          accountType: data.accountType || undefined,
          account: data.accountName || undefined,
          cid: data.userNumber || undefined,
          collegeId: data.collegeId || undefined,
          collegeName: data.collegeName || undefined,
          excludeIds: data.excludeIds || undefined,
          includeIds: data.includeIds || undefined,
          jsdj: data.teacherLevel || undefined,
          jszc: data.StudentDesignation || undefined,
          metroCard: data.oneCardNumber || undefined,
          name: data.name || undefined,
          orgId: data.orgId || undefined,
          schoolId: data.schoolId || undefined,
          schoolName: data.schoolName || undefined,
          showPassword: data.showPassword || undefined,
          status: data.status || undefined,
          pageNo: data.pageNo || undefined,
          pageSize: data.pageSize || undefined,
        },
        accountApi.listPagesUser,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0 ? list.map((item) => publicDataConvert(item)) : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

/**
 * @Post 请求
 *  编辑邮箱
 * @param {*} data
 * {userId} 用户id(账号id) *
 * {email} 邮箱*
 * {captcha} 邮箱验证码 *
 * {checkCode} 校验码 *
 * @param {*} config
 * @returns
 */
function eidtEmail(data = PublicData, config = {}) {
  return request(
    submit(
      {
        user_id: data.userId || undefined,
        email: data.email || undefined,
        captcha: data.captcha || undefined,
        bus_code: data.checkCode || undefined,
      },
      accountApi.eidtEmail,
      config
    )
  );
}

/**
 * @Post 请求
 * 修改手机号码
 * @param {*} data
 * {userId} 用户id(账号id) *
 * {phone} 手机号码 *
 * @param {*} config
 * @returns
 */
function editPhone(data = PublicData, config = {}) {
  return request(
    submit(
      {
        user_id: data.userId || undefined,
        phone: data.phone || undefined,
      },
      accountApi.editPhone,
      config
    )
  );
}

/**
 * @Post 请求
 * 初始化密码
 * @param {*} 传入数组 例子：[1,2,3]
 * @param {*} config
 * @returns
 */
function setPassword(data, config = {}) {
  return request(submit(data, accountApi.setPassword, config));
}
export {
  activeUser,
  lockUser,
  configRoles,
  delBatchUser,
  eidtEmail,
  editPhone,
  getUserById,
  getUserByIdPart,
  listPagesUser,
  listPagesUserPart,
  queryUserListPart,
  queryUserList,
  setPassword,
};
