//行政班接口
import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import adminClassApi from "../api/adminClassApi";
import { request } from "../globalConfiguration";
//行政班接口
const PagesData={ 
  adminName: undefined,
  adminNumber: undefined,
  orgId: undefined,
  orgName: undefined,
  proId: undefined,
  proName: undefined,
  startTime:undefined,
  overTime:undefined,
  time:undefined,
  id:undefined,
  students:undefined,
}
/**
 * @Post 请求
 *添加行政班
 * @param {data} 参数
 * {adminNumber} 行政班编号
 * {adminName} 行政班名称
 * {orgId}  机构id
 * {proId} 专业id
 * {startTime} 开始时间
 * {overTime} 结束时间
 * @param {config} 配置项
 * @returns
 */
function addClaAdmin(
  data = PagesData,
  config = {}
) {
  return request(
    submit(
      {
        xzbbh: data.adminNumber || undefined, //行政班编号
        xzbmc: data.adminName || undefined, //行政班名称
        fkJgId: data.orgId || undefined, // 机构id
        jgmc: data.orgName || undefined, //机构名称
        fkZyId: data.proId || undefined, //专业id
        proName: data.zymc || undefined, //专业名称
        ksrq: data.startTime ||undefined, //开始时间
        jsrq: data.overTime ||undefined, //结束时间
      },
      adminClassApi.addClaAdmin,
      config
    )
  );
}

/**
 * @Post 请求
 *更新行政班
 * @param {data} 参数
 * {id}  行政班id
 * {adminNumber} 行政班编号
 * {adminName} 行政班名称
 * {orgId}  机构id
 * {proId} 专业id
 * {startTime} 开始时间
 * {overTime} 结束时间
 * @param {config} 配置项
 * @returns
 */
function updateClaAdmin(
  data = {
    id: undefined,
   ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //行政班id
        xzbbh: data.adminNumber || undefined, //行政班编号
        xzbmc: data.adminName || undefined, //行政班名称
        fkJgId: data.orgId || undefined, // 机构id
        jgmc: data.orgName || undefined, //机构名称
        fkZyId: data.proId || undefined, //专业id
        zymc: data.proName || undefined, //专业名称
        ksrq: data.startTime ||undefined, //开始时间
        jsrq: data.overTime ||undefined, //结束时间
      },
      adminClassApi.updateClaAdmin,
      config
    )
  );
}

/**
 * @Delete 请求
 *批量删除行政班
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchClaAdmin(data, config = {}) {
  return request(batchDeletion(data, adminClassApi.delBatchClaAdmin, config));
}

/**
 * @Get 请求
 *根据id查询行政班
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getClaAdminById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, adminClassApi.getClaAdminById, config))
      .then(({ result }) => {
        resolve({
          id: result.id || undefined,
          adminNumber: result.xzbbh || undefined,
          adminName: result.xzbmc || undefined,
          orgId: result.fkJgId || undefined, // 机构id
          orgName: result.jgmc || undefined, // 机构名称
          proId: result.fkZyId ||undefined,
          proName: result.zymc ||undefined,
          startTime:result.ksrq ||undefined,
          overTime:result.jsrq ||undefined,
        });
      })
  });
}

/**
 * @Post 请求
 *查询行政班列表
 * @param {data} 参数
 * {adminNumber} 行政班编号
 * {adminName} 行政班名称
 * {orgId}  机构id
 * {proId} 专业id
 * {startTime} 开始时间
 * {overTime} 结束时间
 * @param {config} 配置项
 * @returns
 */
function queryClaAdminList(
  data =PagesData,
  config = {}
) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          xzbbh: data.adminNumber || undefined, //行政班编号
          xzbmc: data.adminName || undefined, //行政班名称
          fkJgId: data.orgId || undefined, // 机构id
          jgmc: data.orgName || undefined, //机构名称
          fkZyId: data.proId || undefined, //专业id
          zymc: data.proName || undefined, //专业名称
          ksrq: data.startTime ||undefined, //开始时间
          jsrq: data.overTime ||undefined, //结束时间
        },
        adminClassApi.queryClaAdminList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          value: item.id || undefined,
          label: item.xzbmc || undefined,
          key:item.id || undefined,
          title:item.xzbmc || undefined,
          orgId: item.fkJgId || undefined,
          orgName: item.jgmc || undefined,
          proId: result.fkZyId ||undefined,
          proName: result.zymc ||undefined,
          adminNumber: result.xzbbh || undefined,
        }))
      );
    });
  });
}

/**
 * @Post 请求
 *分页查询
 * @param {data} 参数
 * {courseName} 行政班名称
 * {orgId}  机构id
 * {courseNumber} 行政班编号
 * 除上面参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesClaAdmin(data=PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          xzbmc: data.adminName || undefined, //行政班名称
          jg_id: data.orgId || undefined, //机构id,jg_id[]
          jgmc: data.orgName || undefined, //机构名称
          zymc: data.proName || undefined, //专业名称
          fkZyId: data.proId || undefined, //专业id
          xzbbh:data.adminNumber||undefined,//行政班编号
          ksrq: data.startTime ||undefined, //开始时间
          jsrq: data.overTime ||undefined, //结束时间
          ksrqAndJsrq:data.time||undefined, //时间
          ...data,
          ...PagesData,
        },
        adminClassApi.listPagesClaAdmin,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  adminNumber: item.xzbbh || undefined,
                  adminName: item.xzbmc || undefined,
                  orgId: item.fkJgId || undefined, // 机构id
                  orgName: item.jgmc || undefined, // 机构名称t
                  proId: item.fkZyId ||undefined,
                  proName: item.zymc ||undefined,
                  time:item.ksrqAndJsrq ||undefined,
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}
/**
 * @Get 请求
 *根据专业id查询行政表的数据
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
 function getByProfessionId(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, adminClassApi.getByProfessionId, config))
      .then(({ result }) => {
        resolve({
          id: result.id || undefined,
          adminNumber: result.xzbbh || undefined,
          adminName: result.xzbmc || undefined,
          orgId: result.fkJgId || undefined, // 机构id
          orgName: result.jgmc || undefined, // 机构名称
          proId: result.fkZyId ||undefined,
          proName: result.zymc ||undefined,
          startTime:result.ksrq ||undefined,
          overTime:result.jsrq ||undefined,
        });
      })
  });
}
/**
 * @Post 请求
 *添加学生到行政班
 * @param {data} 参数
 * {adminNumber} 行政班编号
 * {adminName} 行政班名称
 * {orgId}  机构id
 * {proId} 专业id
 * {startTime} 开始时间
 * {overTime} 结束时间
 * @param {config} 配置项
 * @returns
 */
 function addStudentsClaAdmin(
  data = PagesData,
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //行政班id
        name: data.adminName || undefined, //行政班名称
        students: data.students || undefined, // 添加的学生id列表
      },
      adminClassApi.addStudentsClaAdmin,
      config
    )
  );
}
/**
 * @Delete 请求
 *删除行政班里的学生
 * @param {data} 参数 
 * {students}传入要删除的数组 [] 
 * {id} 行政班id
 * @param {config} 配置项
 * @returns
 */
 function deleteStudentsClaAdmin(data, config = {}) {
  return request(batchDeletion(data, adminClassApi.deleteStudentsClaAdmin, config));
}
export {
  addClaAdmin,
  updateClaAdmin,
  delBatchClaAdmin,
  getClaAdminById,
  queryClaAdminList,
  listPagesClaAdmin,
  getByProfessionId,
  addStudentsClaAdmin,
  deleteStudentsClaAdmin,
};
