import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import campusApi from "../api/campusApi";
import { request } from "../globalConfiguration";
//校区接口
const PagesData={ campusNumber: undefined, campusName: undefined, orgId: undefined };
const QueryData={campusNumber: undefined, campusName: undefined,orgIds: undefined}
/**
 * @Post 请求
 *添加校区
 * @param {data} 参数
 * {campusNumber} 校区编号
 * {campusName} 校区名称
 * {orgId} 学校id add 机构id
 * @param {config} 配置项
 * @returns
 */
function addCampus(
  data = PagesData,
  config = {}
) {
  return request(
    submit(
      {
        xqbh: data.campusNumber || undefined, //校区编号
        xqmc: data.campusName || undefined, //校区名称
        fkJgId: data.orgId || undefined, // 机构id
      },
      campusApi.addCampus,
      config
    )
  );
}

/**
 * @Post 请求
 *更新校区
 * @param {data} 参数
 * {id}  校区id
 * {campusNumber} 校区编号
 * {campusName} 校区名称
 * {orgId} 学校id add 机构id
 * @param {config} 配置项
 * @returns
 */
function updateCampus(
  data = {
    id: undefined,
    ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //校区id
        xqbh: data.campusNumber || undefined, //校区编号
        xqmc: data.campusName || undefined, //校区名称
        fkJgId: data.orgId || undefined, // 机构id
      },
      campusApi.updateCampus,
      config
    )
  );
}

/**
 * @Delete 请求
 *批量删除校区
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchCampus(data, config = {}) {
  return request(batchDeletion(data, campusApi.delBatchCampus, config));
}

/**
 * @Get 请求
 *根据id查询校区
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getCampusById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, campusApi.getCampusById, config))
      .then(({ result }) => {
        resolve({
          id: result.id || undefined,
          campusNumber: result.xqbh || undefined,
          campusName: result.xqmc || undefined,
          orgId: result.fkJgId || undefined, // 机构id
          orgName: result.jgmc || undefined, // 机构名称
        });
      })
      .catch(() => {
        reject({});
      });
  });
}

/**
 * @Post 请求
 *查询校区列表
 * @param {data} 参数
 * {campusNumber} 校区编号
 * {campusName} 校区名称
 * {orgIds} 机构id 数组
 * 分页字段 自定义
 * @param {config} 配置项
 * @returns
 */
function queryCampusList(data=QueryData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          xqbh: data.campusNumber||undefined , //校区编号
          xqmc: data.campusName||undefined, //校区名称
          jgIds: data.orgIds||undefined , // 机构id 数组
          ...data,
          ...PagesData,
        },
        campusApi.queryCampusList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          value: item.id || undefined,
          label: item.xqmc || undefined,
          key:tem.id || undefined,
          title: item.xqmc || undefined,
          orgId: item.fkJgId || undefined,
          orgName: item.jgmc || undefined,
          campusNumber: result.xqbh || undefined,
        }))
      );
    });
  });
}

/**
 * @Post 请求
 *分页查询
 * @param {data} 参数
 * {campusName} 校区名称
 * {orgIds}  机构id 数组
 * 除上面两个参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesCampus(data=QueryData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          xqmc: data.campusName || undefined, //校区名称
          xqbh:data.campusNumber|| undefined, //校区编号
          jgIds: data.orgIds || undefined, //机构ids 数组
          ...data,
          ...QueryData
        },
        campusApi.listPagesCampus,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  campusNumber: item.xqbh || undefined,
                  campusName: item.xqmc  || undefined,
                  orgId: item.fkJgId || undefined, // 机构id
                  orgName: item.jgmc || undefined, // 机构名称
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

export {
  addCampus,
  updateCampus,
  delBatchCampus,
  getCampusById,
  queryCampusList,
  listPagesCampus,
};
