import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import classroomApi from "../api/classroomApi";
import { request } from "../globalConfiguration";
//教室接口
const PagesData = {
  ClassroomNumber: undefined,
  ClassroomName: undefined,
  campusId: undefined,
  teachingBuildingId: undefined,
  orgId: undefined,
  floorId: undefined,
  campusName: undefined,
  teachingBuildingName:undefined,
  orgName:undefined,
  floorName:undefined,
};

const QueryData={
  ids:undefined,
  classroomNumbers:undefined,
  classroomName:undefined,
  campusIds:undefined,
  teachingBuildingName:undefined,
  orgId:undefined
}
/**
 * @Post 请求
 *添加教室
 * @param {data} 参数
 * {classroomNumber} 教室编号  *
 * {classroomName} 教室名称  *
 * {campusId} 校区id  *
 * {teachingBuildingId} 教学楼id *
 * {orgId} 机构id *
 * {floorId} 楼层Id *
 * @param {config} 配置项
 * @returns
 */
function addClassroom(data = PagesData, config = {}) {
  return request(
    submit(
      {
        jsbh: data.ClassroomNumber || undefined, //教室编号
        jsmc: data.ClassroomName || undefined, //教室名称
        fkXqId: data.campusId || undefined, // 校区id
        fkJxlId: data.teachingBuildingId || undefined, // 教学楼id
        fkJgId: data.orgId || undefined, // 机构id
        fkLcId:data.floorId || undefined, // 楼层id
      },
      classroomApi.addClassroom,
      config
    )
  );
}

/**
 * @Post 请求
 *更新教室
 * @param {data} 参数
 * {id}  教室id *
 * {classroomNumber} 教室编号  *
 * {classroomName} 教室名称  *
 * {campusId} 校区id  *
 * {teachingBuildingId} 教学楼id *
 * {orgId} 机构id *
 * {floorId} 楼层Id *
 * @param {config} 配置项
 * @returns
 */
function updateClassroom(
  data = {
    id: undefined,
    ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //教室id
        jsbh: data.classroomNumber || undefined, //教室编号
        jsmc: data.classroomName || undefined, //教室名称
        fkXqId: data.campusId || undefined, // 校区id
        fkJxlId: data.teachingBuildingId || undefined, // 教学楼id
        fkJgId: data.orgId || undefined, // 机构id
        fkLcId:data.floorId || undefined, // 楼层id
      },
      classroomApi.updateClassroom,
      config
    )
  );
}

/**
 * @Delete 请求
 *批量删除教室
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchClassroom(data, config = {}) {
  return request(batchDeletion(data, classroomApi.delBatchClassroom, config));
}

/**
 * @Get 请求
 *根据id查询教室
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getClassroomById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, classroomApi.getClassroomById, config))
      .then(({ result }) => {
        resolve({
          id: result.id || undefined,
          classroomNumber: result.jsbh || undefined,
          classroomName: result.jsmc || undefined,
          campusId: result.fkXqId || undefined, // 校区id
          campusName: result.xqmc || undefined, // 校区名称
          teachingBuildingId: result.fkJxlId || undefined, // 教学楼id
          teachingBuildingName: result.jxlmc || undefined, // 教学楼名称
          orgId: result.fkJgId || undefined, // 机构id
          orgName: result.jgmc || undefined, // 机构名称
          floorId: result.fkLcId || undefined, // 楼层id
          floorName: result.lcmc || undefined, // 楼层名称
        });
      })
      .catch(() => {
        reject({});
      });
  });
}

/**
 * @Post 请求
 *查询教室列表
 * @param {data} 参数
 * {ids} 指定教室列表
 * {classroomNumbers} 指定教室编号列表
 * {classroomName} 教室名称
 * {campusIds} 校区ids 传入数组 []
 * {teachingBuildingName} 教学楼名称
 * {orgId} 机构id
 * @param {config} 配置项
 * @returns
 */
function queryClassroomList(data = QueryData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          ids: data.ids || undefined, //指定教室列表
          jsmc: data.classroomName || undefined, //教室名称
          jxlmc:data.teachingBuildingName || undefined, //教学楼名称
          jsBhs:data.classroomNumbers|| undefined, //指定教室编号列表
          jgId: data.orgId || undefined, // 机构id
          fkXqId: data.campusIds || undefined, // 校区ids 传入数组 []
        },
        classroomApi.queryClassroomList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          id: item.id || undefined,
          value: item.id || undefined,
          key:item.id|| undefined,
          title:item.jsmc || undefined,
          label: item.jsmc || undefined,
          classroomNumber: item.jsbh || undefined,
          classroomName: item.jsmc || undefined,
          campusId: item.fkXqId || undefined, // 校区id
          campusName: item.xqmc || undefined, // 校区名称
          teachingBuildingId: item.fkJxlId || undefined, // 教学楼id
          teachingBuildingName: item.jxlmc || undefined, // 教学楼名称
          orgId: item.fkJgId || undefined, // 机构id
          orgName: item.jgmc || undefined, // 机构名称
          floorId: item.fkLcId || undefined, // 楼层id
          floorName: item.lcmc || undefined, // 楼层名称
        }))
      );
    });
  });
}

/**
 * @Post 请求
 *分页查询
 * @param {data} 参数
* {ids} 指定教室列表
 * {classroomNumbers} 指定教室编号列表
 * {classroomName} 教室名称
 * {campusIds} 校区ids 传入数组 []
 * {teachingBuildingName} 教学楼名称
 * {orgId} 机构id
 * 除上面参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesClassroom(data = QueryData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          ids: data.ids || undefined, //指定教室列表
          jsmc: data.classroomName || undefined, //教室名称
          jxlmc:data.teachingBuildingName || undefined, //教学楼名称
          jsBhs:data.classroomNumbers|| undefined, //指定教室编号列表
          orgId: data.orgId || undefined, // 机构id
          fkXqId: data.campusIds || undefined, // 校区ids 传入数组 []
          ...data,
          ...PagesData,
        },
        classroomApi.listPagesClassroom,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  classroomNumber: item.jsbh || undefined,
                  classroomName: item.jsmc || undefined,
                  campusId: item.fkXqId || undefined, // 校区id
                  campusName: item.xqmc || undefined, // 校区名称
                  teachingBuildingId: item.fkJxlId || undefined, // 教学楼id
                  teachingBuildingName: item.jxlmc || undefined, // 教学楼名称
                  orgId: item.fkJgId || undefined, // 机构id
                  orgName: item.jgmc || undefined, // 机构名称
                  floorId: item.fkLcId || undefined, // 楼层id
                  floorName: item.lcmc || undefined, // 楼层名称
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

export {
  addClassroom,
  updateClassroom,
  delBatchClassroom,
  getClassroomById,
  queryClassroomList,
  listPagesClassroom,
};
