//课程接口
import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import courseApi from "../api/courseApi";
import { request } from "../globalConfiguration";
//课程接口
const PagesData={ courseNumber: undefined,
  courseName: undefined,
  orgId: undefined,
  orgName: undefined,}
/**
 * @Post 请求
 *添加课程
 * @param {data} 参数
 * {courseNumber} 课程编号
 * {courseName} 课程名称
 * {orgId}  机构id
 * @param {config} 配置项
 * @returns
 */
function addCourse(
  data = PagesData,
  config = {}
) {
  return request(
    submit(
      {
        kcbh: data.courseNumber || undefined, //课程编号
        kcmc: data.courseName || undefined, //课程名称
        fkJgId: data.orgId || undefined, // 机构id
        jgmc: data.orgName || undefined, //机构名称
      },
      courseApi.addCourse,
      config
    )
  );
}

/**
 * @Post 请求
 *更新课程
 * @param {data} 参数
 * {id}  课程id
 * {CourseNumber} 课程编号
 * {CourseName} 课程名称
 * {orgId} 学校id add 机构id
 * @param {config} 配置项
 * @returns
 */
function updateCourse(
  data = {
    id: undefined,
   ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //课程id
        kcbh: data.courseNumber || undefined, //课程编号
        kcmc: data.courseName || undefined, //课程名称
        fkJgId: data.orgId || undefined, // 机构id
        jgmc: data.orgName || undefined, //机构名称
      },
      courseApi.updateCourse,
      config
    )
  );
}

/**
 * @Delete 请求
 *批量删除课程
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchCourse(data, config = {}) {
  return request(batchDeletion(data, courseApi.delBatchCourse, config));
}

/**
 * @Get 请求
 *根据id查询课程
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getCourseById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, courseApi.getCourseById, config))
      .then(({ result }) => {
        resolve({
          id: result.id || undefined,
          courseNumber: result.kcbh || undefined,
          courseName: result.kcmc || undefined,
          orgId: result.fkJgId || undefined, // 机构id
          orgName: result.jgmc || undefined, // 机构名称
        });
      })
  });
}

/**
 * @Post 请求
 *查询课程列表
 * @param {data} 参数
 * {CourseNumber} 课程编号
 * {CourseName} 课程名称
 * {orgId} 学校id add 机构id
 * @param {config} 配置项
 * @returns
 */
function queryCourseList(
  data =PagesData,
  config = {}
) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          kcbh: data.courseNumber||undefined, //课程编号
          kcmc: data.CourseName||undefined, //课程名称
          fkJgId: data.orgId||undefined, // 机构id
          fgmc:data.orgName||undefined,//机构名称
        },
        courseApi.queryCourseList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          id: item.id || undefined,
          value: item.id || undefined,
          label: item.kcmc || undefined,
          key: item.id || undefined,
          title: item.kcmc || undefined,
          orgId: item.fkJgId || undefined,
          orgName: item.jgmc || undefined,
          courseNumber: result.kcbh || undefined,
        }))
      );
    });
  });
}

/**
 * @Post 请求
 *分页查询
 * @param {data} 参数
 * {courseName} 课程名称
 * {orgId}  机构id
 * {courseNumber} 课程编号
 * 除上面参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesCourse(data=PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          kcmc: data.courseName || undefined, //课程名称
          fkJgId: data.orgId || undefined, //机构id
          kcbh:data.courseNumber||undefined,//课程编号
          ...data,
          ...PagesData,
        },
        courseApi.listPagesCourse,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  courseNumber: item.kcbh || undefined,
                  courseName: item.kcmc || undefined,
                  orgId: item.fkJgId || undefined, // 机构id
                  orgName: item.jgmc || undefined, // 机构名称
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

export {
  addCourse,
  updateCourse,
  delBatchCourse,
  getCourseById,
  queryCourseList,
  listPagesCourse,
};
