import { submit, singleQuery } from "../publicMethod/PublicMethod.js";
import lessonSettingsApi from "../api/lessonSettingsApi";
import { request } from "../globalConfiguration";

/**
 * @Post 请求
 * 添加节课设置
 * @param {data} 参数
 * {orgId} 机构id *
 * {duration} 节课时长  *
 * {lessonNumber} 日节课数  *
 *
 * lessonSetDetails：[   数组  *
 *  {
 *    id:''  id
 *    sort:'' 排序  number类型  *
 *    schoolTime：''  上课时间  *
 *    quittingTime:'' 下课时间 *
 *    associationId:'' 关联节课配置id *
 *  }
 * ] 上课时间集合
 *
 * @param {config} 配置项
 * @returns
 */
function addLessonSet(data = PagesData, config = {}) {
  return request(
    submit(
      {
        fkJgId: data.orgId || undefined,
        jksc: data.duration || undefined,
        rjks: data.lessonNumber || undefined,
        lessonSetDetails:
          data.lessonSetDetails.length > 0
            ? data.lessonSetDetails.map((item) => ({
                id: item.id,
                fkJkpzId: item.associationId || undefined,
                idx: item.sort || undefined,
                sksj: item.schoolTime || undefined,
                xksj: item.quittingTime || undefined,
              }))
            : [],
      },
      lessonSettingsApi.addLessonSet,
      config
    )
  );
}

/**
 * @Post 请求
 * 更新节课设置
 * @param {data} 参数
 * {orgId} 机构id *
 * {duration} 节课时长  *
 * {lessonNumber} 日节课数  *
 *
 * lessonSetDetails：[   数组  *
 *  {
 *    id:''  id
 *    sort:'' 排序  number类型  *
 *    schoolTime：''  上课时间  *
 *    quittingTime:'' 下课时间 *
 *    associationId:'' 关联节课配置id *
 *  }
 * ] 上课时间集合
 *
 * @param {config} 配置项
 * @returns
 */
function updateLessonSet(data = PagesData, config = {}) {
  return request(
    submit(
      {
        fkJgId: data.orgId || undefined,
        jksc: data.duration || undefined,
        rjks: data.lessonNumber || undefined,
        lessonSetDetails:
          data.lessonSetDetails.length > 0
            ? data.lessonSetDetails.map((item) => ({
                id: item.id,
                fkJkpzId: item.associationId || undefined,
                idx: item.sort || undefined,
                sksj: item.schoolTime || undefined,
                xksj: item.quittingTime || undefined,
              }))
            : [],
      },
      lessonSettingsApi.updateLessonSet,
      config
    )
  );
}

/**
 * @Get 请求
 * 根据id获取节课设置
 * @param {data} 参数 传入要查询的id  {schoolId:''}
 * @param {config} 配置项
 * @returns
 */
function getLessonSetById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQuery(data, lessonSettingsApi.getLessonSetById, config))
      .then(({ result }) => {
        resolve(result);
      })
      .catch((result) => {
        const { rjks, jksc, fkJgId, lessonSetDetails } = result;
        reject({
          orgId: fkJgId,
          duration: jksc,
          lessonNumber: rjks,
          lessonSetDetails: lessonSetDetails.map((item) => ({
            id: item.id,
            sort: item.idx,
            schoolTime: item.sksj,
            quittingTime: item.xksj,
            associationId: item.fkJkpzId,
          })),
        });
      });
  });
}

export { addLessonSet, updateLessonSet, getLessonSetById };
