import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import organizationApi from "../api/organizationApi";
import { request } from "../globalConfiguration";
import multipleArray from "../utils/methods";
//机构接口
const PagesData = {
  orgNumber: undefined,
  orgName: undefined,
  orgType: undefined,
  orgTypeName: undefined,
  parentId: undefined,
};
/**
 * 多层数组转换方法
 * @param {*} data  数组
 * @returns 
 */
 const orgMultipleArray=(data)=>data.length>0?data.map((item)=>({
  id:item.id,
  key:item.id,
  title:item.jgmc,
  value:item.id,
  label:item.jgmc,
  orgType:item.jglx,
  orgTypeName:item.jglxmc,
  orgName:item.jgmc,
  orgNumber:item.jgbm,
  parentId:item.pid,
  children:item.children&&item.children.length>0?orgMultipleArray(item.children):[]
})):[]
/**
 * @Post 请求
 *添加机构
 * @param {data} 参数
 * {orgNumber} 机构编码
 * {orgName} 机构名称
 * {orgType} 机构类型
 * {parentId} 父级id （所属上级id）
 * {schoolId} 所属学校id
 * @param {config} 配置项
 * @returns
 */
function addOrg(
  data = PagesData,
  config = {}
) {
  return request(
    submit(
      {
        jgbm: data.orgNumber || undefined, //机构编码
        jglx: data.orgType || undefined, //机构类型
        jgmc: data.orgName || undefined, //机构名称
        pid: data.parentId, //父级id （所属上级id）
      },
      organizationApi.addOrg,
      config
    )
  );
}

/**
 * @Post 请求
 *更新机构
 * @param {data} 参数
 * {id} 机构id
 * {orgNumber} 机构编码
 * {orgName} 机构名称
 * {orgType} 机构类型
 * {parentId} 父级id （所属上级id）
 * {schoolId} 所属学校id
 * @param {config} 配置项
 * @returns
 */
function updateOrg(
  data = {...PagesData,id:undefined},
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //机构id
        jgbm: data.orgNumber || undefined, //机构编码
        jglx: data.orgType || undefined, //机构类型
        jgmc: data.orgName || undefined, //机构名称
        pid: data.parentId, //父级id （所属上级id）
      },
      organizationApi.updateOrg,
      config
    )
  );
}

/**
 * @Delete 请求
 *批量删除机构
 * @param {data} 参数 传入要删除的数组 []
 *  ids:[]  // 删除的id列表
 * checkLink:false  可选, 是否开启关联数据检测,默认false
 * cascade :false   可选, 是否级联删除,即同时把所有下级都删除,默认false
 * @param {config} 配置项
 * @returns
 */
function delBatchOrg(data, config = {}) {
  return request(batchDeletion(data, organizationApi.delBatchOrg, config));
}

/**
 * @Get 请求
 *根据id查询机构
 * @param {data} 参数 传入要查询的机构id
 * @param {config} 配置项
 * @returns
 */
function getOrgById(data, config = {}) {
  return new Promise((resolve, reject) => {
    return request(
      singleQueryPath(data, organizationApi.getOrgById, config)
    ).then(({ result }) => {
      resolve({
        id: result.id || undefined,
        orgNumber: result.jgbm || undefined,
        orgName: result.jgmc || undefined,
        orgType: result.jglx || undefined,
        orgTypeName: result.jglxmc || undefined,
      });
    });
  });
}

/**
 * @Post 请求
 *分页查询
 * @param {data} 参数
 * {orgNumber} 机构编码
 * {orgName} 机构名称
 * {orgType} 机构类型
 * {parentId} 父级id （所属上级id）
 * 除上面参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesOrg(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          jgbm: data.orgNumber || undefined, //机构编码
          jglx: data.orgType || undefined, //机构类型
          jgmc: data.orgName || undefined, //机构名称
          pid: data.parentId , //父级id （所属上级id）
          ...data,
          ...PagesData,
        },
        organizationApi.listPagesOrg,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? orgMultipleArray(list)
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

/**
 * @Post 请求
 *查询机构列表
 * @param {data} 参数
 * {orgNumber} 机构编码
 * {orgName} 机构名称
 * {orgType} 机构类型
 * {parentId} 父级id （所属上级id）
 * @param {config} 配置项
 * @returns
 */
function queryOrgList(
  data = PagesData,
  config = {}
) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          jgbm: data.orgNumber || undefined, //机构编码
          jglx: data.orgType || undefined, //机构类型
          jgmc: data.orgName || undefined, //机构名称
          pid: data.parentId , //父级id （所属上级id）
          pageNo:data.pageNo||undefined,
          pageSize:data.pageSize||undefined,
        },
        organizationApi.queryOrgList,
        config
      )
    ).then(({ result }) => {
      resolve(orgMultipleArray(result));
    });
  });
}

/**
 * @Post 请求
 *根据姓名模糊查询机构
 * @param {data} 参数
 * {orgNumber} 机构编码
 * {orgName} 机构名称
 * {orgType} 机构类型
 * {parentId} 父级id （所属上级id）
 * @param {config} 配置项
 * @returns
 */
 function queryOrgListTree(
  data = PagesData,
  config = {}
) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          jgbm: data.orgNumber || undefined, //机构编码
          jglx: data.orgType || undefined, //机构类型
          jgmc: data.orgName || undefined, //机构名称
          pid: data.parentId , //父级id （所属上级id）
          pageNo:data.pageNo||undefined,
          pageSize:data.pageSize||undefined,
        },
        organizationApi.queryOrgListTree,
        config
      )
    ).then(({ result }) => 
  {  resolve(orgMultipleArray(result));}
    );
  });
}

/**
 * @Post 请求
 *根据姓名模糊查询机构 分页
 * @param {data} 参数
 * {orgNumber} 机构编码
 * {orgName} 机构名称
 * {orgType} 机构类型
 * {parentId} 父级id （所属上级id）
 * @param {config} 配置项
 * @returns
 */
 function listPagesListTree(
  data = PagesData,
  config = {}
) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          jgbm: data.orgNumber || undefined, //机构编码
          jglx: data.orgType || undefined, //机构类型
          jgmc: data.orgName || undefined, //机构名称
          pid: data.parentId , //父级id （所属上级id）
          pageNo:data.pageNo||undefined,
          pageSize:data.pageSize||undefined,
        },
        organizationApi.listPagesListTree,
        config
      )
    ).then(({ result }) => {
      const { list, pageInfo } = result;
      resolve({
        list:
          list.length > 0
            ? orgMultipleArray(list)
            : [],
        pageInfo: pageInfo,
      });
    });
  });
}

/**
 * @Get 请求
 * 查询某个机构的所有父级机构
 * @param {data} 参数 传入要查询的机构id
 * @param {config} 配置项
 * @returns
 */
function queryingOrgParent(data, config = {}) {
  return new Promise((resolve, reject) => {
    return request(
      singleQueryPath(data, organizationApi.queryingOrgParent, config)
    ).then(({ result }) => {
      resolve(
        result.length > 0
          ? result.map((item) => ({
              id: item.id || undefined,
              orgNumber: item.jgbm || undefined,
              orgName: item.jgmc || undefined,
              orgType: item.jglx || undefined,
            }))
          : []
      );
    });
  });
}

/**
 * @Get 请求
 * 查询某个机构的下级机构
 * @param {data} 参数 传入要查询的机构id
 * @param {config} 配置项
 * @returns
 */
function queryingOrgSons(data, config = {}) {
  return new Promise((resolve, reject) => {
    return request(
      singleQueryPath(data, organizationApi.queryingOrgSons, config)
    ).then(({ result }) => {
      resolve(
        result.length > 0
          ? result.map((item) => ({
              id: item.id || undefined,
              orgNumber: item.jgbm || undefined,
              orgTypeName: result.jglxmc || undefined,
              orgName: item.jgmc || undefined,
              orgType: item.jglx || undefined,
            }))
          : []
      );
    });
  });
}

/**
 * @Get 请求
 * 查询指定机构类型的上级机构
 * @param {data} 参数 传入要查询的机构id
 * @param {config} 配置项
 * @returns
 */
function queryingOrgLookForParent(data, config = {}) {
  return new Promise((resolve, reject) => {
    return request(
      singleQueryPath(data, organizationApi.queryingOrgLookForParent, config)
    ).then(({ result }) => {
      resolve(
        result.length > 0
          ? result.map((item) => ({
              id: item.id || undefined,
              orgNumber: item.jgbm || undefined,
              orgTypeName: result.jglxmc || undefined,
              orgName: item.jgmc || undefined,
              orgType: item.jglx || undefined,
            }))
          : []
      );
    });
  });
}

export {
  addOrg,
  updateOrg,
  delBatchOrg,
  getOrgById,
  queryOrgList,
  listPagesOrg,
  queryingOrgParent,
  queryingOrgSons,
  queryingOrgLookForParent,
  queryOrgListTree,
  listPagesListTree,
};
