import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import otherUserApi from "../api/otherUserApi";
import { request } from "../globalConfiguration";
//其他用户接口

/**
 * @Post 请求
 * 添加其他用户
 * @param {data} 参数
 * {accountStatus} 账号状态
 * {accountType} 账号类型
 * {accountTypeName} 账号类型名称
 * {roleId} 角色Id
 * {roleName} 角色名称
 * {avatarId} 头像id
 * {account} 账号
 * {password} 密码
 * {name} 姓名
 * {age} 年龄
 * {gender} 性别:[1,2]=[男，女]
 * {userNumber} 教工号/学号/编号
 * {orgId} 所属机构id
 * {orgName} 所属机构名称
 * {avatarId} 头像id
 * {avatarUrl} 头像URL
 * {phone} 手机号
 * {email} 邮箱
 * {loginSupport} 登录支持:[single,multiple]=[单用户,多用户]
 * {accValPeriod} 账号有效期
 * {accountStatus} 账号状态
 * {collegeId} 所属学院id
 * {oneCardNumber} 一卡通卡号
 * {oneCardStartDate} 一卡通有效期起日
 * {oneCardEndDate} 一卡通有效期止日
 * {accountStartDate} 账号有效期起日
 * {accountEndDate} 账号有效期止日
 * {birthdayDate} 出生日期
 * @param {config} 配置项
 * @returns
 */
function addOthers(data = {}, config = {}) {
  return request(
    submit(
      {
        accountStatus: data.accountStatus || undefined, //账号状态
        cid: data.userNumber || undefined, //教工号/学号/编号
        csrq: data.birthdayDate || undefined, //出生日期
        dlzc: data.loginSupport || undefined, //登录支持
        fkJgId: data.orgId || undefined, //机构id
        fkJgMc: data.orgName || undefined, //机构名称
        fkJsVal: data.roleId || undefined, //角色Id
        fkJsKey: data.roleName || undefined, //角色名称
        gertx: data.avatarId || undefined, //头像id
        iconUrl: data.aavatarUrl || undefined, //头像Url
        mm: data.password || undefined, // 密码
        nl: data.age || undefined, // 年龄
        sjhm: data.phone || undefined, //手机号
        xb: data.gender || undefined, //性别
        xm: data.name || undefined, //姓名
        yktkh: data.oneCardNumber || undefined, // 一卡通卡号
        yktyxqqr: data.oneCardStartDate || undefined, //一卡通有效期起日
        yktyxqzr: data.oneCardEndDate || undefined, //一卡通有效期止日
        yx: data.email || undefined, //邮箱
        zh: data.account || undefined, //账号
        zhlx: data.accountType || undefined, //账号类型
        zhlxmc: data.accountTypeName || undefined, //账号类型名称
        zhyxqqr: data.accountStartDate || undefined, //账号有效期起日
        zhyxqzr: data.accountEndDate || undefined, //账号有效期止日
      },
      otherUserApi.addOthers,
      config
    )
  );
}

/**
 *更新其他用户
 * @param {data} 参数
 * {id} id
 * {accountStatus} 账号状态
 * {accountType} 账号类型
 * {accountTypeName} 账号类型名称
 * {roleId} 角色Id
 * {roleName} 角色名称
 * {avatarId} 头像id
 * {account} 账号
 * {password} 密码
 * {name} 姓名
 * {age} 年龄
 * {gender} 性别:[1,2]=[男，女]
 * {userNumber} 教工号/学号/编号
 * {orgId} 所属机构id
 * {orgName} 所属机构名称
 * {avatarId} 头像id
 * {avatarUrl} 头像URL
 * {phone} 手机号
 * {email} 邮箱
 * {loginSupport} 登录支持:[single,multiple]=[单用户,多用户]
 * {accValPeriod} 账号有效期
 * {accountStatus} 账号状态
 * {collegeId} 所属学院id
 * {oneCardNumber} 一卡通卡号
 * {oneCardStartDate} 一卡通有效期起日
 * {oneCardEndDate} 一卡通有效期止日
 * {accountStartDate} 账号有效期起日
 * {accountEndDate} 账号有效期止日
 * {birthdayDate} 出生日期
 * @param {config} 配置项
 * @returns
 */
function updateOthers(data = {}, config = {}) {
  return request(
    submit(
      {
        id: data.id || undefined, //其他用户id
        accountStatus: data.accountStatus || undefined, //账号状态
        cid: data.userNumber || undefined, //教工号/学号/编号
        csrq: data.birthdayDate || undefined, //出生日期
        dlzc: data.loginSupport || undefined, //登录支持
        fkJgId: data.orgId || undefined, //机构id
        fkJgMc: data.orgName || undefined, //机构名称
        fkJsVal: data.roleId || undefined, //角色Id
        fkJsKey: data.roleName || undefined, //角色名称
        gertx: data.avatarId || undefined, //头像id
        iconUrl: data.aavatarUrl || undefined, //头像Url
        mm: data.password || undefined, // 密码
        nl: data.age || undefined, // 年龄
        sjhm: data.phone || undefined, //手机号
        xb: data.gender || undefined, //性别
        xm: data.name || undefined, //姓名
        yktkh: data.oneCardNumber || undefined, // 一卡通卡号
        yktyxqqr: data.oneCardStartDate || undefined, //一卡通有效期起日
        yktyxqzr: data.oneCardEndDate || undefined, //一卡通有效期止日
        yx: data.email || undefined, //邮箱
        zh: data.account || undefined, //账号
        zhlx: data.accountType || undefined, //账号类型
        zhlxmc: data.accountTypeName || undefined, //账号类型名称
        zhyxqqr: data.accountStartDate || undefined, //账号有效期起日
        zhyxqzr: data.accountEndDate || undefined, //账号有效期止日
      },
      otherUserApi.updateOthers,
      config
    )
  );
}

/**
 *批量删除其他用户
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchOthers(data, config = {}) {
  return request(batchDeletion(data, otherUserApi.delBatchOthers, config));
}

/**
 *根据id查询其他用户
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getOthersById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, otherUserApi.getOthersById, config))
      .then(({ result }) => {
        resolve({
          id: result.id || undefined,
          accountType: result.zhlx || undefined,
          account: result.zh || undefined,
          name: result.xm || undefined,
          password: result.mm || undefined,
          email: result.yx || undefined,
          phone: result.sjhm || undefined,
          userNumber: result.cid || undefined,
          orgId: result.fkJgId || undefined,
          orgName: result.fkJgMc || undefined,
          loginSupport: result.dlzc || undefined,
          accountStartDate: result.zhyxqqr || undefined,
          accountEndDate: result.zhyxqzr || undefined,
          oneCardNumber: result.yktkh || undefined,
          oneCardStartDate: result.yktyxqqr || undefined,
          oneCardEndDate: result.yktyxqzr || undefined,
          roleName: result.fkJsKey || undefined,
          roleId: result.fkJsVal || undefined,
          avatarId: result.gertx || undefined,
          accountTypeName: result.zhlxmc || undefined,
          accountStatus: result.accountStatus || undefined,
          avatarUrl: result.iconUrl || undefined,
          gender: result.xb || undefined,
          age: result.nl || undefined,
          birthdayDate: result.csrq || undefined,
        });
      })
      .catch(() => {
        reject({});
      });
  });
}

/**
 *查询其他用户列表
 * @param {data} 参数
 * {accountName} 账号名称
 * {userNumber} 教工号/学号/编号
 * {collegeId} 学院id   数组 []
 * {collegeName} 学院姓名
 * {excludeIds} 排除id列表
 * {includeIds} 包含id列表
 * {oneCardNumber} 一卡通号
 * {name} 姓名
 * {orgId} 机构id 数组[]
 * {orgName} 机构姓名
 * {schoolId} 学校Id
 * {schoolName} 学校机构名
 * {showPassword} 是否包含密码, 默认隐藏 true or false
 * {status} 状态
 * {pageNo} 第几页
 * {pageSize} 每页数量
 * @param {config} 配置项
 * @returns
 */
function queryOthersList(data = {}, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          account: data.accountName || undefined,
          cid: data.userNumber || undefined,
          collegeId: data.collegeId || undefined,
          collegeName: data.collegeName || undefined,
          excludeIds: data.excludeIds || undefined,
          includeIds: data.includeIds || undefined,
          metroCard: data.oneCardNumber || undefined,
          name: data.name || undefined,
          orgId: data.orgId || undefined,
          schoolId: data.schoolId || undefined,
          schoolName: data.schoolName || undefined,
          showPassword: data.showPassword || undefined,
          status: data.status || undefined,
          pageNo: data.pageNo || undefined,
          pageSize: data.pageSize || undefined,
        },
        otherUserApi.queryOthersList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          value: item.id || undefined,
          label: item.name || undefined,
          id: item.id || undefined,
          accountType: item.zhlx || undefined,
          account: item.zh || undefined,
          name: item.xm || undefined,
          password: item.mm || undefined,
          email: item.yx || undefined,
          phone: item.sjhm || undefined,
          userNumber: item.cid || undefined,
          orgId: item.fkJgId || undefined,
          orgName: item.fkJgMc || undefined,
          loginSupport: item.dlzc || undefined,
          accountStartDate: item.zhyxqqr || undefined,
          accountEndDate: item.zhyxqzr || undefined,
          oneCardNumber: item.yktkh || undefined,
          oneCardStartDate: item.yktyxqqr || undefined,
          oneCardEndDate: item.yktyxqzr || undefined,
          roleName: item.fkJsKey || undefined,
          roleId: item.fkJsVal || undefined,
          avatarId: item.gertx || undefined,
          accountTypeName: item.zhlxmc || undefined,
          accountStatus: item.accountStatus || undefined,
          avatarUrl: item.iconUrl || undefined,
          gender: item.xb || undefined,
          age: item.nl || undefined,
          birthdayDate: item.csrq || undefined,
        }))
      );
    });
  });
}

/**
 *分页查询
 * @param {data} 参数
 * {accountName} 账号名称
 * {userNumber} 教工号/学号/编号
 * {collegeId} 学院id   数组 []
 * {collegeName} 学院姓名
 * {excludeIds} 排除id列表
 * {includeIds} 包含id列表
 * {oneCardNumber} 一卡通号
 * {name} 姓名
 * {orgId} 机构id 数组[]
 * {orgName} 机构姓名
 * {schoolId} 学校Id
 * {schoolName} 学校机构名
 * {showPassword} 是否包含密码, 默认隐藏 true or false
 * {status} 状态
 * {pageNo} 第几页
 * {pageSize} 每页数量
 * @param {config} 配置项
 * @returns
 */
function listPagesOthers(data = {}, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          account: data.accountName || undefined,
          cid: data.userNumber || undefined,
          collegeId: data.collegeId || undefined,
          collegeName: data.collegeName || undefined,
          excludeIds: data.excludeIds || undefined,
          includeIds: data.includeIds || undefined,
          metroCard: data.oneCardNumber || undefined,
          name: data.name || undefined,
          orgId: data.orgId || undefined,
          schoolId: data.schoolId || undefined,
          schoolName: data.schoolName || undefined,
          showPassword: data.showPassword || undefined,
          status: data.status || undefined,
          pageNo: data.pageNo || undefined,
          pageSize: data.pageSize || undefined,
        },
        otherUserApi.listPagesOthers,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  accountType: item.zhlx || undefined,
                  account: item.zh || undefined,
                  name: item.xm || undefined,
                  password: item.mm || undefined,
                  email: item.yx || undefined,
                  phone: item.sjhm || undefined,
                  userNumber: item.cid || undefined,
                  orgId: item.fkJgId || undefined,
                  orgName: item.fkJgMc || undefined,
                  loginSupport: item.dlzc || undefined,
                  accountStartDate: item.zhyxqqr || undefined,
                  accountEndDate: item.zhyxqzr || undefined,
                  oneCardNumber: item.yktkh || undefined,
                  oneCardStartDate: item.yktyxqqr || undefined,
                  oneCardEndDate: item.yktyxqzr || undefined,
                  roleName: item.fkJsKey || undefined,
                  roleId: item.fkJsVal || undefined,
                  avatarId: item.gertx || undefined,
                  accountTypeName: item.zhlxmc || undefined,
                  accountStatus: item.accountStatus || undefined,
                  avatarUrl: item.iconUrl || undefined,
                  gender: item.xb || undefined,
                  age: item.nl || undefined,
                  birthdayDate: item.csrq || undefined,
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

export {
  addOthers,
  updateOthers,
  delBatchOthers,
  getOthersById,
  queryOthersList,
  listPagesOthers,
};
