import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import professionalApi from "../api/professionalApi";
import { request } from "../globalConfiguration";
//专业接口
const PagesData={ proNumber: undefined, proName: undefined, orgId: undefined }
/**
 * @Post 请求
 *添加专业
 * @param {data} 参数
 * {proNumber} 专业编号
 * {proName} 专业名称
 * {orgId} 学校id add 机构id
 * @param {config} 配置项
 * @returns
 */
function addPro(
  data = PagesData,
  config = {}
) {
  return request(
    submit(
      {
        zybh: data.proNumber || undefined, //专业编号
        zymc: data.proName || undefined, //专业名称
        fkJgId: data.orgId || undefined, // 机构id
      },
      professionalApi.addPro,
      config
    )
  );
}

/**
 * @Post 请求
 *更新专业
 * @param {data} 参数
 * {id}  专业id
 * {proNumber} 专业编号
 * {proName} 专业名称
 * {orgId} 学校id add 机构id
 * @param {config} 配置项
 * @returns
 */
function updatePro(
  data = {
    id: undefined,
    ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //专业id
        zybh: data.proNumber || undefined, //专业编号
        zymc: data.proName || undefined, //专业名称
        fkJgId: data.orgId || undefined, // 机构id
      },
      professionalApi.updatePro,
      config
    )
  );
}

/**
 * @Delete 请求
 *批量删除专业
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchPro(data, config = {}) {
  return request(batchDeletion(data, professionalApi.delBatchPro, config));
}

/**
 * @Get 请求
 *根据id查询专业
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getProById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, professionalApi.getProById, config))
      .then(({ result }) => {
        resolve({
          id: result.id || undefined,
          proNumber: result.zybh || undefined,
          proName: result.zymc || undefined,
          orgId: result.fkJgId || undefined, // 机构id
          orgName: result.jgmc || undefined, // 机构名称
        });
      })
      .catch(() => {
        reject({});
      });
  });
}

/**
 * @Post 请求
 *查询专业列表
 * @param {data} 参数
 * {proNumber} 专业编号
 * {proName} 专业名称
 * {orgId} 学校id add 机构id
 * @param {config} 配置项
 * @returns
 */
function queryProList(data=PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          zybh: data.proNumber||undefined , //专业编号
          zymc: data.proName||undefined, //专业名称
          fkJgId: data.orgId||undefined , // 机构id
        },
        professionalApi.queryProList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          id:item.id || undefined,
          value: item.id || undefined,
          label: item.zymc || undefined,
          key: item.id || undefined,
          title: item.zymc || undefined,
          orgId: item.fkJgId || undefined,
          orgName: item.jgmc || undefined,
          proNumber: result.zybh || undefined,
        }))
      );
    });
  });
}

/**
 * @Post 请求
 *分页查询
 * @param {data} 参数
 * {proName} 专业名称
 * {orgId}  机构id
 * 除上面两个参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesPro(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          zymc: data.proName || undefined, //专业名称
          jgId: data.orgId || undefined, //机构id
          ...data,
          ...PagesData
        },
        professionalApi.listPagesPro,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  proNumber: item.zybh || undefined,
                  proName: item.zymc  || undefined,
                  orgId: item.fkJgId || undefined, // 机构id
                  orgName: item.jgmc || undefined, // 机构名称
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

export {
  addPro,
  updatePro,
  delBatchPro,
  getProById,
  queryProList,
  listPagesPro,
};
