//学期
import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import semesterApi from "../api/semesterApi";
import { request } from "../globalConfiguration";
//学期接口
const PagesData = {
  updownSemester: undefined,
  semesterStart: undefined,
  semesterOver: undefined,
  semesterYear: undefined,
  weekAmount: undefined,
  semesterWeek: undefined,
  semesterName: undefined,
};


/**
 * @Post 请求
 *添加学期
 * @param {data} 参数
 * {semesterName} 学期名称
 * {semesterWeek} 周数
 * {updownSemester} 上下学期，1-上学期，2-下学期 *
 * {semesterStart} 学期周期起始时间 *
 * {semesterOver}  学期周期结束时间 *
 * {semesterYear}  学期年度 *
 * @param {config} 配置项
 * @returns
 */
function semesterAdd(data = PagesData, config = {}) {
  return request(
    submit(
      {
        sxxq: data.updownSemester || undefined, //上下学期，1-上学期，2-下学期
        xqqssj: data.semesterStart || undefined, //学期周期起始时间
        xqjssj: data.semesterOver || undefined, // 学期周期结束时间
        xqnd: data.semesterYear || undefined, //学期年度
      },
      semesterApi.semesterAdd,
      config
    )
  );
}

/**
 *更新学期
 * @Post 请求
 * @param {data} 参数
 * {updownSemester} 上下学期，1-上学期，2-下学期 *
 * {semesterStart} 学期周期起始时间 *
 * {semesterOver}  学期周期结束时间 *
 * {semesterYear}  学期年度 *
 * @param {config} 配置项
 * @returns
 */
function updateSemester(
  data = {
    id: undefined,
    ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //课程id
        sxxq: data.updownSemester || undefined, //上下学期，1-上学期，2-下学期
        xqqssj: data.semesterStart || undefined, //学期周期起始时间
        xqjssj: data.semesterOver || undefined, // 学期周期结束时间
        xqnd: data.semesterYear || undefined, //学期年度
      },
      semesterApi.updateSemester,
      config
    )
  );
}

/**
 *批量删除学期
 * @DELETE 请求
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function semesterDelBatch(data, config = {}) {
  return request(batchDeletion(data, semesterApi.semesterDelBatch, config));
}

/**
 *根据id查询学期
 * @Get 请求
 * {updownSemester} 上下学期，1-上学期，2-下学期 *
 * {semesterStart} 学期周期起始时间 *
 * {semesterOver}  学期周期结束时间 *
 * {semesterYear}  学期年度 *
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getSemesterById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, semesterApi.getSemesterById, config)).then(
      ({ result }) => {
        resolve({
          id: result.id || undefined,
          semesterYear: result.xqnd || undefined, //年度
          updownSemester: result.sxxq || undefined, //上下学期，1-上学期，2-下学期
          semesterStart: result.xqqssj || undefined, //起始时间
          semesterOver: result.xqjssj || undefined, //结束时间
        });
      }
    );
  });
}

/**
 *查询学期列表
 * @param {data} 参数
 * {semesterName} 学期名称
 * @param {config} 配置项
 * @returns
 */
function getSemesterList(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          xqmc: data.semesterName || undefined, //学期名称
          xqnd: data.semesterYear || undefined, //年度
          keyword: data.keyword || undefined, // 关键字
          ...data,
          ...PagesData,
        },
        semesterApi.getSemesterList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          value: item.id || undefined,
          label: item.xqmc || undefined,
          key: item.id || undefined,
          title: item.xqmc || undefined,
          semesterYear:item.xqnd|| undefined,
          semesterStart: item.xqqssj || undefined, //周起始时间
          semesterOver: item.xqjssj || undefined, //周结束时间
          semesterWeek: item.xqzs || undefined,
        }))
      );
    });
  });
}

/**
 *分页查询
 * @param {data} 参数
 * {semesterName} 学期名称
 * {semesterWeek} 周数
 * {semesterStart} 学期周期起始时间
 * {semesterOver}  学期周期结束时间
 * 除上面参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function querySemesterList(data = PagesData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          xqmc: data.semesterName || undefined, //学期名称
          xqqssj: data.semesterStart || undefined, //学期周期起始时间
          xqjssj: data.semesterOver || undefined, // 学期周期结束时间
          xqzs: data.semesterWeek || undefined, //周数
          keyword: data.keyword || undefined, // 关键字
          ...data,
          ...PagesData,
        },
        semesterApi.querySemesterList,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  semesterName: item.xqmc || undefined,
                  semesterStart: item.xqqssj || undefined,
                  semesterOver: item.xqjssj || undefined,
                  semesterWeek: item.xqzs || undefined,
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

export {
  semesterAdd,
  updateSemester,
  semesterDelBatch,
  getSemesterById,
  getSemesterList,
  querySemesterList,
};
