import {
  submit,
  batchDeletion,
  pagingQuery,
  singleQueryPath,
  postQueryData,
} from "../publicMethod/PublicMethod.js";
import teachingBuildingApi from "../api/teachingBuildingApi";
import { request } from "../globalConfiguration";
//教学楼接口
const PagesData={ buildingNumber: undefined, buildingName: undefined, orgId: undefined };
const QueryData={buildingNumber: undefined, buildingName: undefined,orgIds: undefined,campusIds:undefined};
/**
 * @Post 请求 
 *添加教学楼
 * @param {data} 参数
 * {buildingNumber} 教学楼编号 *
 * {buildingName} 教学楼名称 *
 * {orgId} 机构id *
 * {campusId} 校区id *
 * {orgName} 机构名称
 * {campusName} 校区名称
 * @param {config} 配置项
 * @returns
 */
function addTeachingBuilding(
  data = PagesData,
  config = {}
) {
  return request(
    submit(
      {
        jxlbh: data.buildingNumber || undefined, //教学楼编号
        jxlmc: data.buildingName || undefined, //教学楼名称
        fkJgId: data.orgId || undefined, // 机构id
        fkXqId: data.campusId||undefined,//校区id
        xqmc:data.campusName||undefined,//校区名称
        jgmc:data.orgName||undefined,//机构名称
      },
      teachingBuildingApi.addTeachingBuilding,
      config
    )
  );
}

/**
 * @Post 请求 
 *更新教学楼
 * @param {data} 参数
 * {id}  教学楼id *
 * {buildingNumber} 教学楼编号 *
 * {buildingName} 教学楼名称 *
 * {orgId} 机构id *
 * {campusId} 校区id *
 * {orgName} 机构名称
 * {campusName} 校区名称
 * @param {config} 配置项
 * @returns
 */
function updateTeachingBuilding(
  data = {
    id: undefined,
    ...PagesData,
  },
  config = {}
) {
  return request(
    submit(
      {
        id: data.id || undefined, //教学楼id
        jxlbh: data.buildingNumber || undefined, //教学楼编号
        jxlmc: data.buildingName || undefined, //教学楼名称
        fkJgId: data.orgId || undefined, // 机构id
        fkXqId: data.campusId||undefined,//校区id
        xqmc:data.campusName||undefined,//校区名称
        jgmc:data.orgName||undefined,//机构名称
      },
      teachingBuildingApi.updateTeachingBuilding,
      config
    )
  );
}

/**
 * @Delete 请求 
 *批量删除教学楼
 * @param {data} 参数 传入要删除的数组 []
 * @param {config} 配置项
 * @returns
 */
function delBatchTeachingBuilding(data, config = {}) {
  return request(batchDeletion(data, teachingBuildingApi.delBatchTeachingBuilding, config));
}

/**
 * @Get 请求 
 *根据id查询教学楼
 * @param {data} 参数 传入要查询的id
 * @param {config} 配置项
 * @returns
 */
function getTeachingBuildingById(data, config = {}) {
  return new Promise((resolve, reject) => {
    request(singleQueryPath(data, teachingBuildingApi.getTeachingBuildingById, config))
      .then(({ result }) => {
        resolve({
          id: result.id || undefined,
          buildingNumber: result.jxlbh || undefined,
          buildingName: result.jxlmc || undefined,
          orgId: result.fkJgId || undefined, // 机构id
          orgName: result.jgmc || undefined, // 机构名称
          campusId:result.fkXqId || undefined, // 校区名称
          campusName:result.xqmc || undefined, // 校区名称
        });
      })
      .catch(() => {
        reject({});
      });
  });
}

/**
 * @Post 请求 
 *查询教学楼列表
 * @param {data} 参数
 * {buildingNumber} 教学楼编号
 * {buildingName} 教学楼名称
 * {orgIds}  机构id 数组
 * {campusIds} 校区id 数组
 * 分页字段 自定义
 * @param {config} 配置项
 * @returns
 */
function queryTeachingBuildingList(data=QueryData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      postQueryData(
        {
          jxlbh: data.buildingNumber||undefined , //教学楼编号
          jxlmc: data.buildingName||undefined, //教学楼名称
          jgIds: data.orgIds||undefined , // 机构id 数组
          xqIds:data.campusIds||undefined,//校区ids 数组
          ...data,
          ...PagesData,
        },
        teachingBuildingApi.queryTeachingBuildingList,
        config
      )
    ).then(({ result }) => {
      resolve(
        result.map((item) => ({
          id: item.id || undefined,
          value: item.id || undefined,
          label: item.jxlmc || undefined,
          key: item.id || undefined,
          title: item.jxlmc || undefined,
          orgId: item.fkJgId || undefined,
          orgName: item.jgmc || undefined,
          buildingNumber: item.jxlbh || undefined,
          campusId:item.fkXqId || undefined, // 校区名称
          campusName:item.xqmc || undefined, // 校区名称
        }))
      );
    });
  });
}

/**
 * @Post 请求 
 *分页查询
 * @param {data} 参数
 * {buildingName} 教学楼名称
 * {orgIds}  机构id 数组
 * {campusIds} 校区id 数组
 * 除上面两个参数外 其他参数可自定义
 * @param {config} 配置项
 * @returns
 */
function listPagesTeachingBuilding(data=QueryData, config = {}) {
  return new Promise((resolve, reject) => {
    request(
      pagingQuery(
        {
          jxlmc: data.buildingName || undefined, //教学楼名称
          jxlbh:data.buildingNumber|| undefined, //教学楼编号
          jgIds: data.orgIds || undefined, //机构ids 数组
          xqIds:data.campusIds||undefined,//校区ids 数组
          ...data,
          ...QueryData
        },
        teachingBuildingApi.listPagesTeachingBuilding,
        config
      )
    )
      .then(({ result }) => {
        const { list, pageInfo } = result;
        resolve({
          list:
            list.length > 0
              ? list.map((item) => ({
                  id: item.id || undefined,
                  buildingNumber: item.jxlbh || undefined,
                  buildingName: item.jxlmc  || undefined,
                  orgId: item.fkJgId || undefined, // 机构id
                  orgName: item.jgmc || undefined, // 机构名称
                  campusId:item.fkXqId || undefined, // 校区名称
                  campusName:item.xqmc || undefined, // 校区名称
                }))
              : [],
          pageInfo: pageInfo,
        });
      })
      .catch((err) => {
        reject(err);
      });
  });
}

export {
  addTeachingBuilding,
  updateTeachingBuilding,
  delBatchTeachingBuilding,
  getTeachingBuildingById,
  queryTeachingBuildingList,
  listPagesTeachingBuilding,
};
